@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: SQLite setup/teardown for tests
 
-our $VERSION = '0.0408';
+our $VERSION = '0.0409';
 
 use DBI;
 use File::Copy;
@@ -130,7 +130,7 @@ Test::SQLite - SQLite setup/teardown for tests
 
 =head1 VERSION
 
-version 0.0408
+version 0.0409
 
 =head1 SYNOPSIS
 
@@ -226,10 +226,7 @@ be ignored.
 
 Create a new C<Test::SQLite> object.
 
-=head2 BUILD
-
-Ensure that we are only given one of B<database>, B<schema> or
-B<memory> in the constructor.
+=for Pod::Coverage BUILD
 
 =head1 SEE ALSO
 
